@@ -13,11 +13,6 @@ class PyPI_TestCase(unittest.TestCase):
         with self.assertRaises(PackageNotFound):
             pypi.get_available_versions('abcxyz')
 
-    def test_get_source_url(self):
-        pypi = PyPI()
-        self.assertEqual(pypi.get_latest_source_distribution_url('ipython'),
-                         'https://pypi.python.org/packages/source/i/ipython/ipython-1.2.1.tar.gz')
-
     def test_download(self):
         import stat
         import os
@@ -40,11 +35,6 @@ class DjangoPyPI_TestCase(unittest.TestCase):
         with self.assertRaises(PackageNotFound):
             pypi.get_available_versions('abcxyz')
 
-    def test_get_source_url(self):
-        pypi = DjangoPyPI("pypi01.infinidat.com")
-        self.assertEqual(pypi.get_latest_source_distribution_url('ipython'),
-                'http://pypi01.infinidat.com//media/dists/ipython-1.2.1.tar.gz#md5=4ffb36697f7ca8cb4a2de0f5b30bc89c')
-
     def test_download(self):
         import stat
         import os
